/*
 * fancysaxdtdhandler.h
 *
 *  Created on: 28.07.2010
 *      Author: wglas
 */

#ifndef FANCYSAXDTDHANDLER_H_
#define FANCYSAXDTDHANDLER_H_

#include <fancyobject.h>
#include <fancysax.h>

namespace Fancy {

namespace SAX {

/**
 * A minimal callback interface for DTD events. FOr parsing ordinary documents
 * you most likely do not need to implement this interface.
 */
class FANCYSAX_API DTDHandler: public virtual Fancy::Object {

public:
    typedef Fancy::ObjPtr<DTDHandler> ptr_t;

    /**
     * Return a new default instance, which does debug logging and nothing else.
     */
    static ptr_t newDefaultInstance();

    /**
     * An entity definition has been parsed.
     *
     * @param ctx  the user data (XML parser context)
     * @param name  the entity name
     * @param type  the entity type
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     * @param content the entity value (without processing).
     */
    virtual void entityDecl (const char *name,
                     int type,
                     const char *publicId,
                     const char *systemId,
                     char *content);

    /**
     * What to do when a notation declaration has been parsed.
     *
     * @param ctx  the user data (XML parser context)
     * @param name The name of the notation
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     */
    virtual void notationDecl(const char *name,
                              const char *publicId,
                              const char *systemId);


    /**
     * What to do when an unparsed entity declaration is parsed.
     *
     * @param ctx  the user data (XML parser context)
     * @param name The name of the entity
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     * @param notationName the name of the notation
     *
     */
    virtual void unparsedEntityDecl(const char *name,
                            const char *publicId,
                            const char *systemId,
                            const char *notationName);

protected:
    DTDHandler();
    virtual ~DTDHandler();
};

}}
#endif /* FANCYSAXDTDHANDLER_H_ */
