/*
 * fancysaxentityresolver.h
 *
 *  Created on: 28.07.2010
 *      Author: wglas
 */

#ifndef FANCYSAXENTITYRESOLVER_H_
#define FANCYSAXENTITYRESOLVER_H_

#include <fancyobject.h>
#include <fancysax.h>

namespace Fancy {

class Channel;

namespace SAX {

/**
 * An interface for resolving XML entites.
 */
class FANCYSAX_API EntityResolver: public virtual Fancy::Object {

public:
    typedef Fancy::ObjPtr<EntityResolver> ptr_t;

    /**
     * Callback:
     * The entity loader, to control the loading of external entities,
     * the application can either:
     *    - override this resolveEntity() callback in the SAX block
     *    - or better use the xmlSetExternalEntityLoader() function to
     *      set up it's own entity resolution routine
     *
     * @param ctx  the user data (XML parser context)
     * @param publicId The public ID of the entity
     * @param systemId The system ID of the entity
     *
     * @return A channel set up for read the resolved entity or NULL for DOM behaviour.
     */
    virtual Fancy::ObjPtr<Fancy::Channel> resolveEntity (const char *publicId,
                                                         const char *systemId) = 0;

protected:
    EntityResolver();
    virtual ~EntityResolver();
};

}
}

#endif /* FANCYSAXENTITYRESOLVER_H_ */
