/*
 * fancysaxparser.h
 *
 *  Created on: 28.07.2010
 *      Author: wglas
 */

#ifndef FANCYSAXPARSER_H_
#define FANCYSAXPARSER_H_

#include <fancyobject.h>
#include <fancysax.h>

namespace Fancy {

class Channel;

namespace SAX {

class ContentHandler;
class DTDHandler;
class EntityResolver;

/**
 * A SAX parser interface.
 */
class FANCYSAX_API Parser: public virtual Fancy::Object {

public:
    typedef Fancy::ObjPtr<Parser> ptr_t;

    /**
     * @return A new parser instance using the given content handler.
     *         You may set a @c DTDHandler and an @c EntityResolver using the
     *         supplied setters.
     */
    static ptr_t newInstance(const Fancy::ObjPtr<ContentHandler> &contentHandler);

    virtual Fancy::ObjPtr<ContentHandler> getContentHandler() const = 0;
    virtual void setContentHandler(const Fancy::ObjPtr<ContentHandler> &contentHandler) = 0;

    virtual Fancy::ObjPtr<DTDHandler> getDTDHandler() const = 0;
    virtual void setDTDHandler(const Fancy::ObjPtr<DTDHandler> &dtdHandler) = 0;

    virtual Fancy::ObjPtr<EntityResolver> getEntityResolver() const = 0;
    virtual void setEntityResolver(const Fancy::ObjPtr<EntityResolver> &entityResolver) = 0;

    /**
     * Parse the XML document from the given channel.
     */
    virtual void parse(const Fancy::ObjPtr<Fancy::Channel> &channel) = 0;

protected:
    Parser();
    virtual ~Parser();
};

}

}

#endif /* FANCYSAXPARSER_H_ */
