/*
 * fancysaxtaghandler.h
 *
 *  Created on: 28.07.2010
 *      Author: wglas
 */

#ifndef FANCYSAXTAGHANDLER_H_
#define FANCYSAXTAGHANDLER_H_

#include <fancyobject.h>
#include <fancysax.h>

namespace Fancy {

namespace SAX {

/**
 * A simplified SAX handler, which plays in combination with @c SimpleContentHandler
 * as a handler for a single XML tag in a stack of handlers.
 */
class FANCYSAX_API TagHandler: public virtual Fancy::Object {

public:
    typedef Fancy::ObjPtr<TagHandler> ptr_t;

    /**
     * Receiving some chars from the parser.
     *
     * @param ctx  the user data (XML parser context)
     * @param ch  an UTF-8 encoded string
     * @param len the number of UTF-8 characters
     */
    virtual void characters (const char *ch,
                             int len) = 0;

    /**
     * SAX2 callback when a child element of the current element starts.
     * It provides the namespace informations for the element, as well as
     * the new namespace declarations on the element.
     *
     * @param localname  the local name of the element
     * @param prefix  the element namespace prefix if available
     * @param URI  the element namespace name if available
     * @param nb_namespaces  number of namespace definitions on that node
     * @param namespaces  pointer to the array of prefix/URI pairs namespace definitions
     * @param nb_attributes  the number of attributes on that node
     * @param nb_defaulted  the number of defaulted attributes. The defaulted
     *                  ones are at the end of the array @c attributes.
     * @param attributes  pointer to the array of (localname/prefix/URI/value/end)
     *                    attribute values. This array has a size of @c nb_attributes.
     * @return A tag handler for the child element or @c null, if the content of the
     *         child element should be ignored.
     */
    virtual ptr_t startChildElementNs (const char * localname,
                                       const char * prefix,
                                       const char * URI,
                                       int nb_namespaces,
                                       const char ** namespaces,
                                       int nb_attributes,
                                       int nb_defaulted,
                                       const Attribute* attributes) = 0;
    /**
     * SAX2 callback when the element of this handler ends.
     * It provides the namespace informations for the element.
     *
     * @param localname  the local name of the element
     * @param prefix  the element namespace prefix if available
     * @param URI  the element namespace name if available
     */
    virtual void endElementNs (const char * localname,
                               const char * prefix,
                               const char * URI) = 0;

protected:
    TagHandler();
    virtual ~TagHandler();
};

}

}

#endif /* FANCYSAXTAGHANDLER_H_ */
